@@ -48,16 +48,10 @@ dot_names <- function(dots) unname(unlist(lapply(dots, as.character)))
 #' @importFrom stats complete.cases
 #' @importFrom rlang .data
 get_grouped_data <- function(x) {
-  # nest data frame
-  grps <- tidyr::nest(x)
-
-  # remove NA category
-  cc <- grps %>%
-    dplyr::select(-.data$data) %>%
-    stats::complete.cases()
-
-  # select only complete cases
-  grps <- grps %>% dplyr::filter(!! cc)
+  # retain observations that are complete wrt grouping vars, then nest
+  grps <- x %>%
+    dplyr::group_modify(~ dplyr::filter(.x, stats::complete.cases(.y))) %>%
+    tidyr::nest()
 
   # arrange data
   if (length(dplyr::group_vars(x)) == 1)
