@@ -15,7 +15,7 @@ if (!requireNamespace("mediation", quietly = TRUE)) {
   warning("Package 'mediation' required for this vignette.", call. = FALSE)
 }
 if (!requireNamespace("httr", quietly = TRUE)) {
-  warning("Package 'mediation' required for this vignette.", call. = FALSE)
+  warning("Package 'httr' required for this vignette.", call. = FALSE)
 }
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -34,35 +34,16 @@ b2 <- lm(depress2 ~ treat + job_seek + econ_hard + sex + age, data = jobs)
 # mediation analysis, for comparison with brms
 m1 <- mediate(b1, b2, sims = 1000, treat = "treat", mediator = "job_seek")
 
-# load Bayesian models
-m2 <- insight::download_model("brms_mv_6")
-m3 <- insight::download_model("brms_zi_2")
-
-## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-tidy_stan(m3)
-
-## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-tidy_stan(m3, typical = "mean")
-
-## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-# printing fixed and random effects of multilevel model
-tidy_stan(m3, effects = "all")
-
-## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-# printing fixed and random effects of multilevel model, 
-# only zero-inflated model part.
-tidy_stan(m3, effects = "all", component = "zero_inflated")
-
-## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-# two different HDI for multivariate response model
-tidy_stan(m2, prob = c(.5, .95))
-
 ## ----eval=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  # Fit Bayesian mediation model
 #  f1 <- bf(job_seek ~ treat + econ_hard + sex + age)
 #  f2 <- bf(depress2 ~ treat + job_seek + econ_hard + sex + age)
 #  
 #  m2 <- brm(f1 + f2 + set_rescor(FALSE), data = jobs, cores = 4)
 
+## ----echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+m2 <- insight::download_model("brms_mv_6")
+
 ## ---- message=TRUE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 mediation(m2)
 
